# Mouth2
[![pypi version](https://img.shields.io/pypi/v/mouth2-oc.svg)](https://pypi.org/project/mouth2-oc) ![MIT License](https://img.shields.io/pypi/l/mouth2-oc.svg)

Body 2.0 service that handles outgoing communications like emails and sms
messages.

Please see [LICENSE](https://github.com/ouroboroscoding/mouth2/blob/main/LICENSE)
for further information.

# Documentation

[RESTful](https://github.com/ouroboroscoding/mouth2/blob/main/rest.md)